"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isValidAthClaim = void 0;
const crypto_1 = require("crypto");
const base64url_1 = require("jose/util/base64url");
/**
 * Verifies the DPoP Proof ath claim
 * The base64url encoded SHA-256 hash of the ASCII encoding of the associated access token's value.
 * See also: https://datatracker.ietf.org/doc/html/draft-ietf-oauth-dpop-03#section-4.2
 */
function isValidAthClaim(accessToken, athClaim) {
    return (base64url_1.encode(crypto_1.createHash("sha256").update(Buffer.from(accessToken, "ascii")).digest()) === athClaim);
}
exports.isValidAthClaim = isValidAthClaim;
//# sourceMappingURL=isValidAthClaim.js.map